@@ -2,12 +2,15 @@ from __future__ import annotations
 import typing as t
 import logging
 from functools import partial
-from .context import Context  # noqa:F401
-from .v2.codegen import SchemaWriter  # noqa:F401
 from .config import ConfigDict
+from .context import Context
+from .context import OneFileContextFactory, SeparatedFilesContextFactory
+from .v2.codegen import SchemaWriter  # noqa:F401
 
 if t.TYPE_CHECKING:
     from swagger_marshmallow_codegen.resolver import Resolver
+    from .context import InputData
+    from .context import OutputData
 
 logger = logging.getLogger(__name__)
 
@@ -40,23 +43,26 @@ class Codegen:
         self.schema_writer_factory = schema_writer_factory
 
     def codegen(
-        self,
-        d,
-        config: ConfigDict,
-        *,
-        ctx: t.Optional[Context] = None,
-        test: bool = False,
-    ):
-        if test:
-            # todo: use dataclasses?
-            config["skip_header_comment"] = True
-
-        cls = self.guess_factory(d, config=config, path=self.version_path)
-        codegen = cls(
+        self, d: InputData, config: ConfigDict, *, ctx: t.Optional[Context] = None,
+    ) -> OutputData:
+        codegen_cls = self.guess_factory(d, config=config, path=self.version_path)
+        codegen = codegen_cls(
             schema_class_path=self.schema_class_path,
             schema_writer_factory=self.schema_writer_factory,
         )
-        return codegen.codegen(d, ctx=ctx)
+        if config.get("separated_output", False):
+            context_factory_cls = SeparatedFilesContextFactory
+        else:
+            context_factory_cls = OneFileContextFactory
+
+        context_factory = context_factory_cls(
+            ctx or Context(), setup=codegen.setup_context
+        )
+        try:
+            return codegen.codegen(d, context_factory=context_factory)
+        finally:
+            if context_factory.teardown is not None:
+                context_factory.teardown(codegen.accessor.resolver)
 
     def guess_factory(
         self, d: t.Dict, *, config: ConfigDict, path: str
